-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009, 2010, 2011, 2012, 2013 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org

newTalent{
	short_name = "WEAKENING_AURA",
	name = "Weakening Aura",
	type = {"corruption/corrupted nature", 1},
	require = spells_req1,
	mode = "sustained",
	points = 5,
	sustain_vim = 20,
	cooldown = 0,
	range = 3,
	no_energy = true,
	tactical = { BUFF = 5 },
	getChance = function(self, t) return self:combatLimit(self:getTalentLevel(t)^.5, 100, 7, 1, 15.65, 2.23) end, -- Limit < 100%
	getDuration = function(self, t)
		return 3
	end,
	activate = function(self, t)
		game:playSoundNear(self, "talents/arcane")
		return {
			particle = self:addParticles(Particles.new("gloom", 1)),
		}
	end,
	deactivate = function(self, t, p)
		self:removeParticles(p.particle)
		return true
	end,
	callbackOnAct = function(self, t)
		if game.zone.wilderness or not self:isTalentActive(t.id) then return end		
		local spellpower = self:combatSpellpower()*1.5
		local grids = core.fov.circle_grids(self.x, self.y, self:getTalentRange(t), true)
		for x, yy in pairs(grids) do
			for y, _ in pairs(grids[x]) do
				local target = game.level.map(x, y, Map.ACTOR)
				if target and self:reactionToward(target) < 0 then				
					-- Gloom
					if rng.percent(t.getChance(self, t)) and target:checkHit(spellpower, target:combatSpellResist(), 5, 95, 15) then
						target:setEffect(target.EFF_WEAKENED_BY_AURA, 5, {src = self, power=self:combatSpellpower()/2})
						--hit = true
					end
				end
			end
		end
	end,
	info = function(self, t)
		return ([[%d %% chance to weaken foes within radius 3. Weakened foes have thier saves reduced by half of your spellpower and they have a chance to spread existing diseases based on your spellpower and thier health.]]):format(t.getChance(self, t))
	end,
}

newTalent{
	short_name="VIM_CASTING",
	name = "Vim Casting",
	type = {"corruption/corrupted nature", 2},
	require = spells_req2,
	mode = "activated",
	random_ego = "attack",
	points = 5,
	cooldown = 15,
	tactical = { ATTACK = { BLIGHT = 1}},
	dur = function(self, t) return self:combatTalentScale(t, 4, 8) end,
	action = function(self, t)
		self:setEffect(self.EFF_VIM_CASTING, t.dur(self, t), {})
		return true
	end,
	info = function(self, t)
		return ([[Force nature to do your bidding for %d turns, whenever you fail an equilibrium check you will still use the talent but your vim is reduced by the failure chance.]]):format(t.dur(self, t))
	end,
}

newTalent{
	short_name = "TWISTED",
	name = "Twisted",
	type = {"corruption/corrupted nature", 3},
	require = spells_req3,
	mode = "sustained",no_sustain_autoreset = true,
	random_ego = "buff",
	points = 5,
	cooldown = 10,
	sustain_vim = 0,
	range = 0,
	radius = 3,
	tactical = {BUFF = { PHYSICAL = 2 } } ,
	requires_target = true,
	target = function(self, t)
		return {type="ball", radius=self:getTalentRadius(t), friendlyfire = true, selffire=true, range=0, talent=t}
	end,
	getDamage = function(self, t)
		return self:combatTalentSpellDamage(t, 28, 190)
	end,
	getMindpowerReduc = function(self, t)
		return self:combatTalentScale(t, 10, 5)
	end,
	mind = 0,
	activate = function(self, t)
		if(self.combat_mindpower < t.getMindpowerReduc(self, t))then --Why would you ever want negative mindpower
			t.mind = self:addTemporaryValue("combat_mindpower", -self.combat_mindpower)
		else
			t.mind = self:addTemporaryValue("combat_mindpower", -t.getMindpowerReduc(self, t))
		end
		return true
	end,
	deactivate = function(self, t)
		local tg = self:getTalentTarget(t)
		local grids = self:project(tg, self.x, self.y, DamageType.MANABURN, self:spellCrit(t.getDamage(self, t)))
		game.level.map:particleEmitter(self.x, self.y, tg.radius, "ball_arcane", {radius=tg.radius})
		game:playSoundNear(self, "talents/arcane")
		self:incEquilibrium(-math.ceil(t.getDamage(self, t)/2))
		if not t.mind then else
			self:removeTemporaryValue("combat_mindpower", t.mind)
		end
		return true
	end,
	info = function(self, t)
		return ([[You devote %d mindpower to reducing the consequences caused by using vim, reduces equilibrium penalty from using vim to be only half the vim cost instead of five times the vim cost. This still comes at a cost, when corruption talents are used it will put a random nonsustained wild-gift on cooldown. When deactivated deals %d manaburn damage in radius 3 that effects the caster as well and lower's equilibrium by %d]]):format(t.getMindpowerReduc(self, t),self.damDesc(self, DamageType.ARCANE, t.getDamage(self, t)), math.ceil(t.getDamage(self, t)/2))
	end,
}


newTalent{
	short_name = "VIM_SHELL",
	name = "Vim Shell",
	type = {"corruption/corrupted nature", 4},
	require = spells_req4,
	random_ego = "defensive",
	points = 5,
	cooldown = 20,
	sustain_vim = 20,
	drain_vim = 10,
	remove_on_zero = true,
	mode = "sustained",
	minDam = function(self, t)
		return	(.6/self:getTalentLevel(t))
	end,
	activate = function(self, t)
		return true
	end,
	deactivate = function(self, t)
		return true
	end,
	info = function(self, t)
		return ([[Whenever you are dealt damage greater than %0.2f %% of your current life you condense the blight around you into a protective shell negating the damage and asorbing 1/3 the damage over 5 turns. This powerful spell drains 10 vim per turn.]]):format(t.minDam(self, t)*100)
	end,
}


