-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009, 2010, 2011, 2012, 2013 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org

local _M = loadPrevious(...)

newEffect{
	name = "VIM_CASTING", image = "talents/life_linked.png",
	desc = "Vim Casting", status = "beneficial",
	long_desc = function(self, eff) return(("When the user has a equilibrium failure, the talent is still activated but the user will be drained vim equal to the failure chance."):format(eff.power)) end,
	type = "magical",
	subtype = {natue=true},
	parameters = {},
	on_gain = function(self, err) return "#Target# is vim casting!", "+Vim Casting" end,
	on_lose = function(self, err) return "#Target# is no longer vim casting.", "-Vim Casting" end, 
	activate = function(self, eff)
		self.no_equilibrium_fail = true
	end,
	deactivate = function(self, eff)
		self.no_equilibrium_fail = false
	end,
	}

newEffect{
	name = "WEAKENED_BY_AURA", image = "effects/spydric_poison.png",
	desc = "Weakened by Aura",
	long_desc = function(self, eff) return(("The target is weakened, reducing all saves by %d and spreading diseases."):format(eff.power)) end,
	type = "magical",
	subtype = {natue=true},
	parameters = {power = 10},
	on_gain = function(self, err) return "#Target# is weakened by aura!", "+Weakened by Aura" end,
	on_lose = function(self, err) return "#Target# is no longer weakened.", "-Weakened by Aura" end,
	activate = function(self, eff)
		eff.spell = self:addTemporaryValue("combat_spellresist", -eff.power)
		eff.phys = self:addTemporaryValue("combat_physresist", -eff.power)
		eff.mind = self:addTemporaryValue("combat_mindresist", -eff.power)
	end,
	on_timeout = function(self, eff)
		eff.src:callTalent(eff.src.T_EPIDEMIC, "do_spread", self, eff.power*2)
	end,
	deactivate = function(self, eff)
		self:removeTemporaryValue("combat_spellresist", eff.spell)
		self:removeTemporaryValue("combat_physresist", eff.phys)
		self:removeTemporaryValue("combat_mindresist", eff.mind)
	end,}

newEffect{
	name = "PARALYZING_VENOM", image = "effects/spydric_poison.png",
	desc = "Paralyzing Venom",
	long_desc = function(self, eff) return ("The target is poisoned, taking %0.2f nature damage per turn and becoming somewhat paralyzed slowing it by 15%%."):format(eff.power) end,
	type = "physical",
	subtype = { poison=true, pin=true, nature=true }, no_ct_effect = true,
	status = "detrimental",
	parameters = {power=10},
	on_gain = function(self, err) return "#Target# is poisoned and is slowed!", "+Paralysing Venom" end,
	on_lose = function(self, err) return "#Target# is no longer poisoned.", "-Paralysing Venom" end,
	activate = function(self, eff)
		eff.tmpid = self:addTemporaryValue("global_speed_add", -.15)
	end,
	on_timeout = function(self, eff)
		if self:attr("purify_poison") then self:heal(eff.power, eff.src)
		else DamageType:get(DamageType.NATURE).projector(eff.src, self.x, self.y, DamageType.NATURE, eff.power)
		end
	end,
	deactivate = function(self, eff)
		self:removeTemporaryValue("global_speed_add", eff.tmpid)
	end,
}

newEffect{
	name = "MANA_TOXIN", image = "talents/mana_toxin.png",
	desc = "Mana-Toxin",
	long_desc = function(self, eff) return ("The target is infected with a mana-toxin, taking %0.2f manaburn damage per turn, if there are no arcane energies to burn than the target will take %0.2f arcane damage"):format(eff.power, (eff.power/3)) end,
	type = "magical",
	subtype = { poison=true, nature=true }, no_ct_effect = true,
	status = "detrimental",
	parameters = {power=10},
	on_gain = function(self, err) return "#Target# is infected with a mana-toxin!", "+Mana-Toxin" end,
	on_lose = function(self, err) return "#Target# is no longer infected with a mana-toxin.", "-Mana-Toxin" end,
	on_timeout = function(self, eff)
		if (self:getMana() + self:getVim() + self:getPositive() + self:getNegative() > 0)
		then DamageType:get(DamageType.MANABURN).projector(eff.src, self.x, self.y, DamageType.MANABURN, eff.power)
		else DamageType:get(DamageType.ARCANE).projector(eff.src, self.x, self.y, DamageType.ARCANE, (eff.power)/3)
		end
		if eff.src then
			eff.src:incEquilibrium(-math.ceil(eff.power/30.0))
		end
	end,
}