-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009, 2010, 2011, 2012, 2013 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org


newTalent{
	short_name = "CORROSIVE_SPLASH",
	name = "Corrosive Splash",
	type = {"wild-gift/toxins", 1},
	require = gifts_req1,
	random_ego = "attack",
	points = 5,
	cooldown = 5,
	equilibrium = 5,	
	tactical = { ATTACKAREA = 2},
	range = 5,
	radius = function(self, t) return math.floor(self:combatTalentScale(t, 1.3, 3)) end,
	direct_hit = true,
	requires_target = true,
	target = function(self, t)
		return {type="ball", range=self:getTalentRange(t), radius=self:getTalentRadius(t), friendlyfire = true}
	end,
	getDamage = function(self, t)
		return self:combatTalentMindDamage(t, 0, 280)
	end,
	getDur = function(self, t)
		return self:combatTalentMindDamage(t, 4, 10)
	end,
	action = function(self, t)
		local tg = self:getTalentTarget(t)
		local x, y = self:getTarget(tg)
		if not x or not y then return nil end
		local grids = self:project(tg, x, y, function(px, py)
			local target = game.level.map(px, py, Map.ACTOR)
			if not target then return end
			local tx, ty = util.findFreeGrid(x, y, 5, true, {[Map.ACTOR]=true})
			local dam = self:mindCrit(self:combatTalentMindDamage(t, 5, 30))
			local atk = self:combatTalentMindDamage(t, 15, 35)
			local armor = self:combatTalentMindDamage(t, 15, 40)
			target:setEffect(target.EFF_ACID_SPLASH, t.getDur(self, t), {src=self, dam=dam, atk=atk, armor=armor})
		end)
		self:project (tg, x, y, DamageType.ACID, self:mindCrit(t.getDamage(self, t)))
		game.level.map:particleEmitter(x, y, 1, "ball_acid")
		game:playSoundNear(self, "talents/earth")
		return true
	end,	
	info = function(self, t)
		local dam = self:combatTalentMindDamage(t, 5, 30)
		local atk = self:combatTalentMindDamage(t, 15, 35)
		local armor = self:combatTalentMindDamage(t, 15, 40)
		local dur = t.getDur(self, t)
		return ([[Splashes the targeted area within a radius of %d ,dealing an initial %d Acid damage.
		Effected targets will also be splashed with acid dealing Acid damage, reducing armour by %d, and reducing attack by %d
		 for %d turns]]):format(t.radius(self, t), self.damDesc(self, DamageType.ACID, t.getDamage(self,t)), armor, atk, dur)
	end,
}

newTalent{
	short_name = "MANA_TOXIN",
	name = "Mana-Toxin",
	type = {"wild-gift/toxins", 2},
	require = gifts_req2,
	random_ego = "attack",
	points = 5,
	cooldown = 3,
	equilibrium = 5,
	tactical = {ATTACK = { PHYSICAL = 2 } } ,
	range = 5,
	requires_target = true,
	getDamage = function(self, t)
		return 5 + self:combatTalentMindDamage(t, 10, 100)
	end,
	getDur = function(self, t)
		return self:mindCrit(2 + self:combatTalentMindDamage(t, 2, 10))
	end,
	action = function(self, t)
		local tg = {type="bolt", range=self:getTalentRange(t)}
		local x, y = self:getTarget(tg)
		if not x or not y then return nil end

		-- Try to rot !
		self:project(tg, x, y, function(px, py)
			local target = game.level.map(px, py, engine.Map.ACTOR)
			if not target or (self:reactionToward(target) >= 0) then return end
			target:setEffect(self.EFF_MANA_TOXIN, t.getDur(self, t), {src=self, power=self:mindCrit(t.getDamage(self, t)), apply_power=self:combatMindpower()})
			game.level.map:particleEmitter(px, py, 1, "voidblast")
		end)
		return true
	end,
	info = function(self, t)
		local damage = t.getDamage(self, t)
		local eq = math.ceil(damage/30.0)
		return ([[Infects the target with a mana-toxin for %d turns dealing %d manaburn damage.
		If the target has no arcane energies to burn the toxin will deal %d arcane damage instead.
		Each turn of the effect your equilibrium will be reduced by %d .]]):format(t.getDur(self, t), self.damDesc(self, DamageType.ARCANE, damage), self.damDesc(self, DamageType.ARCANE, damage/3), eq)
	end,
}

newTalent{
	short_name = "PARALYZING_VENOM",
	name = "Paralyzing Venom",
	type = {"wild-gift/toxins", 3},
	require = gifts_req3,
	random_ego = "attack",
	points = 5,
	cooldown = 10,
	equilibrium = 10,
	tactical = { ATTACK = { NATURE = 1, poison = 1} },
	range = 8,
	direct_hit = true,
	requires_target = true,
	getDamage = function(self, t)
		return self:combatScale(self:getWil()*self:getTalentLevel(t), 20, 0, 300, 400)
	end,
	action = function(self, t)
		local tg = {type="bolt", range=self:getTalentRange(t)}
		local x, y = self:getTarget(tg)
		if not x or not y then return nil end
		self:project(tg, x, y, DamageType.PARALYZING_POISON, t.getDamage(self,t), {type="slime"})
		game:playSoundNear(self, "talents/slime")
		return true
	end,
	info = function(self, t)
		return ([[Spit venom at your target, doing %0.2f poison damage each turn and slowing them by 15%%.
		The damage will increase with your Willpower.]]):
		format(self.damDesc(self, DamageType.POISON, t.getDamage(self,t)/6))
	end,
}

newTalent{
	short_name = "POISONED_KNOWLEDGE",
	name = "Poisoned Knowledge",
	type = {"wild-gift/toxins", 4},
	require = gifts_req4,
	random_ego = "defensive",
	points = 5,
	cooldown = 5,
	mode = "passive",
	getDiseaseImmune = function(self, t) return self:combatTalentLimit(t, 1, 0.2, 0.75) end, -- Limit < 100%
	do_poison = function(self, t, target)
		if self:isTalentCoolingDown(t) then return true elseif target:canBe("poison") then
			self:startTalentCooldown(t)
			self:logCombat(target, "#LIGHT_BLUE##Source# bites #Target# and injects them with paralysing venom!", self.name:capitalize(), target.name)
			local t = self:getTalentFromId(self.T_PARALYZING_VENOM)
			target:setEffect(self.EFF_PARALYZING_VENOM, 5, {src=self, power=self:mindCrit(t.getDamage(self, t)), apply_power=self:combatMindpower()})
		end
		return true
	end,
	trigger = function(self, t, target)
		self:startTalentCooldown(t)
		self:logCombat(target, "#LIGHT_BLUE##Source# uses the #Target#'s spell as a conduit to infect them with a mana-toxin!", self.name:capitalize(), target.name)	
		local t = self:getTalentFromId(self.T_MANA_TOXIN)
		target:setEffect(self.EFF_MANA_TOXIN, t.getDur(self, t), {src=self, power=self:mindCrit(t.getDamage(self, t)), apply_power=self:combatMindpower()})
		return true
	end,
	passives = function(self, t, p)
		self:talentTemporaryValue(p, "disease_immune", t.getDiseaseImmune(self, t))
		self:talentTemporaryValue(p, "poison_immune", t.getDiseaseImmune(self, t))
	end,
	info = function(self, t)
		local res = t.getDiseaseImmune(self, t) * 100
		return ([[Increases poison and disease resistances by %d%%.
		At talent level 3, foes that attack you with a spell will automatically be infected with a mana-toxin.
		At talent level 5, foes that attack you in melee will automatically be injected with paralysing venom.
		The damage and duration of the casted toxins are based off of thier respective talents, both autocasts share the same cooldown.
		]]):format(res)
	end,
}


